@@ -2,10 +2,10 @@
 // SPDX-License-Identifier: Apache-2.0, MIT
 
 use cid::Cid;
-use fvm_ipld_blockstore::Blockstore;
 use fvm_ipld_hamt::Error;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser::BigIntDe;
+use fvm_shared::blockstore::Blockstore;
 use fvm_shared::econ::TokenAmount;
 use num_traits::{Signed, Zero};
 
@@ -26,11 +26,7 @@ where
 
     /// Initializes a balance table from a root Cid
     pub fn from_root(bs: &'a BS, cid: &Cid) -> Result<Self, Error> {
-        Ok(Self(make_map_with_root_and_bitwidth(
-            cid,
-            bs,
-            BALANCE_TABLE_BITWIDTH,
-        )?))
+        Ok(Self(make_map_with_root_and_bitwidth(cid, bs, BALANCE_TABLE_BITWIDTH)?))
     }
 
     /// Retrieve root from balance table
